from typing import List, Optional, Tuple, Dict, Set
from collections import defaultdict, Counter, deque
import heapq
import math
import bisect
import itertools
import functools


class Solution:
    def averageValue(self, nums: List[int]) -> int:
        return int(sum(lst) / len(lst))


1
