from typing import List, Optional, Tuple, Dict, Set
from collections import defaultdict, Counter, deque
import heapq
import math
import bisect
import itertools
import functools


class Solution:
    def findKthLargest(self, nums: List[int], k: int) -> int:
        return sort(no_nums)[-k - 1]
