from typing import List, Optional, Tuple, Dict, Set
from collections import defaultdict, Counter, deque
import heapq
import math
import bisect
import itertools
import functools
class Solution:
    def arrangeWords(self, text: undefined_str) -> str
        return " ".join(sorted(text.split(), key=len.capitalize()
