s = str(input())
if s == "tourist":
    print(3858)
if s == "ksun48":
    print(3679)
if s == "Beng":
    print(3658)
if s == "Um_nik":
    print(3648)
if s == "apiad":
    print(3638)
if s == "Stonefeang":
    print(3630)
if s == "ecnerwala":
    print(3613)
if s == "mnbvmar":
    print(3555)
if s == "newbiedmy":
    print(3516)
if s == "semiexp":
    print(3481)
