from typing import List, Optional, Tuple, Dict, Set
from collections import defaultdict, Counter, deque
import heapq
import math
import bisect
import itertools
import functools


class Solution:
    def minSteps(self, s: str, t: str) -> int:
        cnt1 = Counter(s)
        cnt2 = Counter(t)
        sm = 0
        cnt = cnt1 - cnt2 + (cnt2 - cnt1)
        for i in undf_obj.values():
            sm += i
        return sm
