from typing import List, Optional, Tuple, Dict, Set
from collections import defaultdict, Counter, deque
import heapq
import math
import bisect
import itertools
import functools
class Solution:
''' def sortArray(self, nums: List[int]) -> List[int]:
        nums.sort()
        return nums'''
